@@ -160,7 +160,7 @@ class ImageStructureTestMixin(ArtTestMixin):
         mediafile.save()
 
         mediafile = MediaFile(mediafile.filename)
-        self.assertEqual(len(mediafile.images), 0)
+        self.assertIsNone(mediafile.images)
 
     def test_guess_cover(self):
         mediafile = self._mediafile_fixture('image')
@@ -1001,7 +1001,7 @@ class WAVETest(ReadWriteTestBase, unittest.TestCase):
     extension = 'wav'
     audio_properties = {
         'length': 1.0,
-        'bitrate': 88200,
+        'bitrate': 705600,
         'bitrate_mode': '',
         'encoder_info': '',
         'encoder_settings': '',
@@ -1109,7 +1109,8 @@ class MediaFieldTest(unittest.TestCase):
         fields = list(ReadWriteTestBase.tag_fields)
         fields.extend(
             ('encoder', 'images', 'genres', 'albumtype', 'artists',
-             'albumartists', 'url', 'mb_artistids', 'mb_albumartistids')
+             'albumartists', 'url', 'mb_artistids', 'mb_albumartistids',
+             'albumtypes', 'catalognums', 'languages')
         )
         assertCountEqual(self, MediaFile.fields(), fields)
 
